# Welcome to nangs

> Solving Partial Differential Equations with Neural Networks.

Nangs is a Python library built on top of Pytorch to solve Partial Differential Equations.

Our objective is to develop a new tool for simulating nature, using Neural Networks as solution approximation to Partial Differential Equations, increasing accuracy and optimization speed while reducing computational cost.

Read our [paper](https://arxiv.org/abs/1912.04737) to know more.

## Installing

nangs is on PyPI so you can just run:

`pip install nangs`

You will also need to install [Pytorch](https://pytorch.org/).

## Getting Started

- Learn how to work with nangs with our [tutorials](https://github.com/juansensio/nangs/tree/master/tutorials).
- See nangs in actions with our [examples](https://github.com/juansensio/nangs/tree/master/examples).

## Copyright

Copyright 2020 onwards, SensioIA. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this project's files except in compliance with the License. A copy of the License is provided in the LICENSE file in this repository.
